==> termtyper-1.1.3.tar.gz: termtyper-1.1.3/README.md <==
# termtyper

### `termtyper` is a terminal based typing practice command-line application written in Python3 using curses library

### Installation
> `pip install termtyper`

**Note:** windows users may need to install `windows-curses`  package (`pip install windows-curses`).\
 And works fine with windows terminal except resize terminal.\
(windows terminal can be installed from microsoft store).



### Usage of command
Just type `termtyper` on terminal to start application

usage: termtyper [-h] [--version] [--upgrade]

### Features
- Onscreen keyboard to see typing effect and has option to toggle onscreen keyboard.
- Can be customized the typing test challenge with 1 minute, 2 minute, 3 minute, 5 minute and 10 minute.
- Can be customized the typing test language with English(six categories) or Programming languages (12 languages)
- Timer starts when first key is pressed and has option to pause/resume the typing test.


### Versions

#### 1.1.3
> No major changes, small adjustment in command-line arguments, and updated README file  
#### 1.1.2
> no changes (just fixed typo in my name in the setup file )
#### 1.1.1
> added coomand line argument feature to upgrade (if latest version available) and for getting version information
##### 1.1.0
> pause/resume the typing test feature has been added in this version.
#### 1.0.1
> added help message to display when terminal is too small to fit onscreen keyboard
##### 1.0.0
> First version

### Languages

The following languages are available

#### English
>1. Top 50 words
>2. Top 100 words
>3. Top 200 words
>4. Top 300 words
>5. Too 500 words
>6. Top 1000 words

#### Programming 
>1. C/CPP
>2. C#
>3. Java
>4. Python
>5. Swift
>6. HTML
>7. Java Script
>8. GO
>9. PHP
>10. Ruby
>11. Kotlin
>12. Rust

### Challanges
The following practice challenges available
>- 1 minute test
>- 2 minute test
>- 3 minute test
>- 5 minute test
>- 10 minute test

==> termtyper-1.1.4.tar.gz: termtyper-1.1.4/README.md <==
# termtyper

### `termtyper` is a terminal based typing practice command-line application written in Python3 using curses library. It can run on mac/lunux/unix and also windows

### Installation
> `pip install termtyper`

**Note:** On windows it works with windows terminal but one issue is it crashes when we resize the terminal.\
(windows terminal can be installed from microsoft store).


### Usage of command
Just type `termtyper` on terminal to start application

usage: termtyper [-h] [--version] [--upgrade]

### Features
- Onscreen keyboard to see typing effect and has option to toggle onscreen keyboard.
- Can be customized the typing test challenge with 1 minute, 2 minute, 3 minute, 5 minute and 10 minute.
- Can be customized the typing test language with English(six categories) or Programming languages (12 languages)
- Timer starts when first key is pressed and has option to pause/resume the typing test.


### Versions

#### 1.1.4
> Bug fix: install_requires keyword in setup.py(now windows-curses package will be autometically installed as required package for windows system)
#### 1.1.3
> No major changes, small adjustment in command-line arguments, and updated README file  
#### 1.1.2
> No changes (just fixed typo in my name in the setup file )
#### 1.1.1
> Added command line argument feature to upgrade (if latest version available) and for getting version information
##### 1.1.0
> Pause/resume the typing test feature has been added in this version.
#### 1.0.1
> Added help message to display when terminal is too small to fit onscreen keyboard
##### 1.0.0
> First version

### Languages

The following languages are available

#### English
>1. Top 50 words
>2. Top 100 words
>3. Top 200 words
>4. Top 300 words
>5. Too 500 words
>6. Top 1000 words

#### Programming 
>1. C/CPP
>2. C#
>3. Java
>4. Python
>5. Swift
>6. HTML
>7. Java Script
>8. GO
>9. PHP
>10. Ruby
>11. Kotlin
>12. Rust

### Challanges
The following practice challenges available
>- 1 minute test
>- 2 minute test
>- 3 minute test
>- 5 minute test
>- 10 minute test
